<?php
class ExtWizardAction extends CAction {
	
	public function run() {
		
		$wizard = $this->attachBehavior('registerWizard',array(
			'class'=>'application.components.WizardBehavior',
			'uniqueId'=>'registerWizard',
			'actions'=>array(
        		array('start','title'=>'START','view'=>'wizardPage'),
        		array('page1','title'=>'wizardry kindergarten'),
        		array('page2','title'=>'wizardry school'),
        		array('page3','title'=>'wizardry university'),
        		array('finish','title'=>'FINISH')),
        	'visibleMode'=>false,
        	'maxSessions'=>10
        ));
        
        /*
         * Must have the following handlers
         *  
         */
//        $wizard->attachEventHandler('onError',array($this,'validateHandler'));
//        $wizard->attachEventHandler('onValidate',array($this,'validateHandler'));
//        $wizard->attachEventHandler('onStart',array($this,'startHandler'));
//        $wizard->attachEventHandler('onNavigate',array($this,'navigationHandler'));
//        $wizard->attachEventHandler('onFinish',array($this,'finishHandler'));

        //start the wizard without autoloading its wizard id
      	$this->runWizard();
	}
	
	public function errorHandler(CEvent $event) {
		switch($event->sender->errorCode) {
			case WizardBehavior::ERR_ACTION_NOT_FOUND:
				throw new CHttpException(400,'Your request could not be processed, please start a new wizard process');
				break 1;
				
			case WizardBehavior::ERR_SESSION_LIMIT_REACHED:
				throw new CHttpException(413,'You reached your connection limit, please end some of your wizards');
				break 1;
				
			case WizardBehavior::ERR_WID_EXPIRED:
				throw new CHttpException(410,'Your wizard session expired, please start a new wizard process');
				break 1;
			
			case WizardBehavior::ERR_WID_NOT_FOUND:
				throw new CHttpException(400,'Could not connect with wizard, no id was given');
				break 1;
			
			default:
				throw new CHttpException(500);
		}
		
		throw new CHttpException($wizard->errorCode,'Your wizard id exceeded');
	}
	
	
	public function validateHandler(CEvent $event) {
		$wizard = $event->sender;
		
		//see method description
        if (!$wizard->hasId() && 0!==$wizard->getStep()) {
        	$this->getController()->redirect($wizard->getStepUrl(0));
        }
        
		if (isset($_POST['back'])) {
			$this->processInput($wizard);
			$wizard->redirect($this->getStep('',-1));
		}
		
		$page = $wizard->getStepUrl($wizard->getCurrentStep());
		$wizard->setState('validationResult','I have validated page: '.$page);
    }
	
	
    public function startHandler(CEvent $event) {
    	$this->getController()->layout = 'column2';
    	$wizard = $event->sender;
    	
    	$formData['name'] = 'Enter your name';
    	$formData['color'] = 'black';
    	$formData['profession'] = 'Describe your profession';
    	
    	$wizard->setState('formData',$formData);
		$wizard->redirect($wizard->getStep('',1));
    }
    
	public function navigationHandler(CEvent $event) {
		//SETUP LAYOUT AND PAGE STATE
		$c = $this->getController();
		$c->layout = 'column2';
		
		//GET WIZARD (using $this would also work but this way seems to be more clear to me)
		$wizard = $event->sender;
		
		//SETUP OF PREVIOUS, CURRENT AND NEXT PAGE INFO
		$step=$wizard->getCurrentStep(); //equivalent to getStep() if no parameters are passed to the latter
		$c->pageInfo[-1]['stepNr'] = $wizard->getStep('',-1);
		$c->pageInfo[-1]['action'] = $wizard->getAction($c->pageInfo[-1]['stepNr']);
		$c->pageInfo[-1]['title'] = $wizard->getTitle($c->pageInfo[-1]['stepNr']); 
		
		$c->pageInfo[0]['stepNr'] = $step;
		$c->pageInfo[0]['action'] = $wizard->getCurrentAction();
		$c->pageInfo[0]['title'] = $wizard->getTitle(); 
		
		$c->pageInfo[1]['stepNr'] = $step+1;
		$c->pageInfo[1]['action'] = $wizard->getAction($c->pageInfo[1]['stepNr']);
		$c->pageInfo[1]['title'] = $wizard->getTitle($c->pageInfo[1]['stepNr']); 
		
		//SETUP DEMO OF ITEMS USAGE
		$this->setupMenus();
		
		//PROCESSING OF USER INPUT
		$this->processInput($wizard);
		
		//NAVIGATE TO NEXT PAGE
		if (empty($_POST['formData']['name'])) {
			$this->getController()->render('wizardPage',array(
				'wizardId'=>$wizard->getWizardId(),
				'stepNr'=>$step,
				'action'=>$wizard->getAction($step),
				'title'=>$wizard->getTitle($step),
				'formData'=>$wizard->getState('formData'),
				'page'=>$this->getStepUrl($step)
			));
		} else {
			$wizard->redirect($wizard->getStep('',1));
		}
    }
    
	public function finishHandler(CEvent $event) {
		$c = $this->getController();
		$c->layout = 'column2';
		$c->setPageState($this->queryParam,$this->getWizardId());	
		$this->setupMenus();
		$c->render('wizardFinish');
    }
    
    private function processInput($wizard) {
    	//RETRIEVE PAGE STATE
		$formData = $wizard->getState('formData',array());
		//ENSURE USER INPUT IS ARRAY FORMAT
		$userInput = (empty($_POST['formData']))? array() : $_POST['formData'];
		//PROCESS USER INPUT
		$formData = array_merge($formData,$userInput);
		//UPDATE FORM DATA WITH PROCESSED INPUT
		$formData = $wizard->setState('formData',$formData);
    }
    
    private function setupMenus() {
    	/*
		 * create action menu items without first and last action and wizardId invisible in url.
		 * Notice that using that kind of link won't send any user input on form elements of the 
		 * current page unless some client side javascript ensures the usage of some send form
		 * button. Above all if you do not use a javascript or if it is disabled on clients machine 
		 * using any link of this menu will result in a loss of the current wizardId 
		 * unless you have not stored it as a session variable. In general if you can't
		 * guarantee that javascript is running on your clients browser you should abstain
		 * from using this kind of page navigation.
		 */
        $this->getController()->menu = $this->getItems( array('start','finish'),false );
        /**
         * create action menu items for all actions and with the wizardId is visible in url.
         * Notice that you'll still loose any form input done by a user on the current page 
         * unless some javascript ensures the send button is being pressed using this link.
         */
        $this->getController()->menu2 = $this->getItems( array(),true );
    }
}