<?php

class SiteController extends Controller
{
	
	var $pageInfo;
	
	/**
	 * Declares class-based actions.
	 */
	public function actions()
	{
		return array(
			'extWizard'=>'application.controllers.ExtWizardAction',
		);
	}

	/**
	 * This is the default 'index' action that is invoked
	 * when an action is not explicitly requested by users.
	 */
	public function actionIndex()
	{
		// renders the view file 'protected/views/site/index.php'
		// using the default layout 'protected/views/layouts/main.php'
		$this->render('index');
	}

	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
	    if($error=Yii::app()->errorHandler->error)
	    {
	    	if(Yii::app()->request->isAjaxRequest)
	    		echo $error['message'];
	    	else
	        	$this->render('error', $error);
	    }
	}


	/**
	 * Displays the login page
	 */
	public function actionLogin()
	{
		$model=new LoginForm;

		// if it is ajax validation request
		if(isset($_POST['ajax']) && $_POST['ajax']==='login-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}

		// collect user input data
		if(isset($_POST['LoginForm']))
		{
			$model->attributes=$_POST['LoginForm'];
			// validate user input and redirect to the previous page if valid
			if($model->validate() && $model->login())
				$this->redirect(Yii::app()->user->returnUrl);
		}
		// display the login form
		$this->render('login',array('model'=>$model));
	}

	/**
	 * Logs out the current user and redirect to homepage.
	 */
	public function actionLogout()
	{
		Yii::app()->user->logout();
		$this->redirect(Yii::app()->homeUrl);
	}
	
	public function actionWizard()
	{
		$wizard = $this->attachBehavior('registerWizard',array(
			'class'=>'application.components.WizardBehavior',
			'actions'=>array(
        		array('start','title'=>'START'),
        		array('page1','title'=>'wizard kindergarten'),
        		array('page2','title'=>'wizard school'),
        		array('page3','title'=>'wizard university'),
        		array('finish','title'=>'FINISH')),
        	'sessionTimeout'=>1200,
        	'createMenu'=>false
        ));
        
        //setup RegisterAction event handlers
        $wizard->attachEventHandler('onStart',array($this,'startHandler'));
        $wizard->attachEventHandler('onNavigate',array($this,'navigationHandler'));
        $wizard->attachEventHandler('onFinish',array($this,'finishHandler'));
        
        //Initialize Wizards Menu
        $this->createMenu( array('new','finish') );
        
        //start the wizard
      	$this->callWizard();
	}
	
    public function startHandler(CEvent $event) {
		$this->render('wizardStart');
    }
    
	public function navigationHandler(CEvent $event) {
		$this->render('wizard1');
		$this->render('wizard2');
		$this->render('wizard3');		
    }
    
	public function finishHandler(CEvent $event) {
		$this->render('wizardFinish');
    }
}